@@ -6,8 +6,8 @@
 ;; Maintainer: TEC <contact@tecosaur.net>
 ;; Created: February 06, 2021
 ;; Modified: February 06, 2021
-;; Package-Version: 20250925.1637
-;; Package-Revision: 10bf72a616ea
+;; Package-Version: 20251028.1701
+;; Package-Revision: 09a6a64dd07a
 ;; Keywords: convenience, frames
 ;; Homepage: https://github.com/tecosaur/emacs-everywhere
 ;; Package-Requires: ((emacs "28.1"))
@@ -921,6 +921,36 @@ Should end in a newline to avoid interfering with the buffer content."
       (require 'ox-md)
       (org-export-to-buffer (if (featurep 'ox-gfm) 'gfm 'md) (current-buffer)))))
 
+(defun emacs-everywhere--potential-cmds (capability)
+  "Return a list of potential commands for CAPABILITY.
+Returns a list of strings/symbols.
+Strings are command names, symbols are function names."
+  (pcase-let ((`(,compositor . ,desktop) (emacs-everywhere--system-compositor)))
+    (let (cands)
+      (dolist (sysconf (reverse emacs-everywhere-system-configs))
+        (let ((match-compositor (or (car-safe (car sysconf)) (car sysconf)))
+              (match-desktop (cdr-safe (car sysconf)))
+              (settings (cdr sysconf))
+              (val (plist-get (cdr sysconf) capability)))
+          (when (and val
+                     (or (not match-compositor)
+                         (eq match-compositor compositor))
+                     (or (not match-desktop)
+                         (eq match-desktop desktop)))
+            (cond
+             ((not (consp val)))
+             ((and (equal (car val) "sh")
+                   (equal (cadr val) "-c"))
+              (push (or (car (split-string-shell-command (caddr val))) "")
+                    cands))
+             ((stringp (car val))
+              (push (car val) cands))
+             ((and (consp (car val)) (stringp (caar val)))
+              (dolist (cmd (reverse val))
+                (when (stringp (car-safe cmd))
+                  (push (car cmd) cands))))))))
+      cands)))
+
 (defun emacs-everywhere-check-health ()
   "Check whether emacs-everywhere has everything it needs."
   (interactive)
@@ -930,30 +960,48 @@ Should end in a newline to avoid interfering with the buffer content."
   (with-silent-modifications
     (erase-buffer)
     (emacs-everywhere--ensure-system-configured)
-    (let ((compositor-display (emacs-everywhere--system-compositor)))
+    (let ((compositor-display (emacs-everywhere--system-compositor))
+          missing-capability)
       (insert (propertize "Emacs Everywhere system health check\n" 'face 'outline-1)
-              "operating system: " (propertize (symbol-name system-type) 'face 'font-lock-type-face)
-              ", display server: " (propertize (symbol-name (car compositor-display)) 'face 'font-lock-type-face)
+              "operating system: " (propertize (symbol-name system-type) 'face 'font-lock-builtin-face)
+              ", display server: " (propertize (symbol-name (car compositor-display)) 'face 'font-lock-builtin-face)
               (and (cdr compositor-display)
-                   (concat "/" (propertize (symbol-name (cdr compositor-display)) 'face 'font-lock-type-face)))
+                   (concat "/" (propertize (symbol-name (cdr compositor-display)) 'face 'font-lock-builtin-face)))
               "\n")
-      (pcase-dolist (`(,capability . ,cmd)
-                     `(("paste" . ,emacs-everywhere--paste-command)
-                       ("copy" . ,emacs-everywhere--copy-command)
-                       ("focus window" . ,emacs-everywhere--window-focus-command)
-                       ("app info" . ,(not (eq emacs-everywhere--app-info-function #'ignore)))
-                       ("pandoc conversion" . ,(and (executable-find "pandoc") (list "pandoc")))))
-        (insert (propertize (format "• %s " capability) 'face `(:inherit outline-4 :height ,(face-attribute 'default :height))))
+      (pcase-dolist (`(,capname ,capsym ,cmd)
+                     `(("paste" :paste-command ,emacs-everywhere--paste-command)
+                       ("copy" :copy-command ,emacs-everywhere--copy-command)
+                       ("focus window" :focus-command ,emacs-everywhere--window-focus-command)
+                       ("app info" :info-function ,(not (eq emacs-everywhere--app-info-function #'ignore)))
+                       ("pandoc conversion" :pandoc-cmd ,(and (executable-find "pandoc") (list "pandoc")))))
+        (insert (propertize (format "• %s " capname) 'face `(:inherit outline-4 :height ,(face-attribute 'default :height))))
         (cond
          ((not cmd)
-          (insert (propertize "unavailible ✗\n" 'face '(error font-lock-comment-face))))
+          (setq missing-capability t)
+          (insert (propertize "unavailable ✗" 'face '(error font-lock-comment-face)))
+          (when-let (cmds (or (emacs-everywhere--potential-cmds capsym)
+                              (and (eq capsym :pandoc-cmd) (list "pandoc"))))
+            (insert (propertize " consider installing " 'face 'italic))
+            (while cmds
+              (insert (propertize (car cmds) 'face '(warning font-lock-comment-face)))
+              (setq cmds (cdr cmds))
+              (insert (cond
+                       ((cdr cmds) ", ")
+                       (cmds ", or ")
+                       (t "")))))
+          (insert "\n"))
          ((consp cmd)
+          (setq missing-capability t)
           (insert "via " (propertize (if (equal (car cmd) "sh")
                                          (car (split-string-shell-command (or (caddr cmd) "?")))
                                        (car cmd))
                                      'face '(success font-lock-constant-face))
                   (propertize " ✓\n" 'face 'success)))
-         (t (insert (propertize "availible ✓\n" 'face 'success))))))))
+         (t (insert (propertize "available ✓\n" 'face 'success)))))
+      (when missing-capability
+        (insert "\nSome capabilities are missing.\nInstall the suggested commands or configure `"
+                (propertize "emacs-everywhere-system-configs" 'face 'font-lock-variable-name-face)
+                "' to enable them.\n")))))
 
 (provide 'emacs-everywhere)
 ;;; emacs-everywhere.el ends here
